==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebGridSelectionRangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDetailDescription } from "./WebGridSelectionRangeDetailDescription";
/**
 * @hidden
 */
var WebGridSelectionRangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSelectionRangeDetailDescriptionMetadata, _super);
    function WebGridSelectionRangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSelectionRangeDetailDescriptionMetadata.b = function (a) {
        if (WebGridSelectionRangeDetailDescriptionMetadata.a == null) {
            WebGridSelectionRangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSelectionRangeDetailDescriptionMetadata.c(WebGridSelectionRangeDetailDescriptionMetadata.a);
        }
        if (a.j(WebGridSelectionRangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSelectionRangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("RowStart", "Number:double");
        a.item("RowEnd", "Number:double");
        a.item("ColumnStart", "String");
        a.item("ColumnEnd", "String");
    };
    WebGridSelectionRangeDetailDescriptionMetadata.d = function (a) {
        WebGridSelectionRangeDetailDescriptionMetadata.b(a);
        a.aa("WebGridSelectionRangeDetail", function () { return new WebGridSelectionRangeDetailDescription(); });
        a.z("WebGridSelectionRangeDetail", WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.$t = markType(WebGridSelectionRangeDetailDescriptionMetadata, 'WebGridSelectionRangeDetailDescriptionMetadata');
    WebGridSelectionRangeDetailDescriptionMetadata.a = null;
    return WebGridSelectionRangeDetailDescriptionMetadata;
}(Base));
export { WebGridSelectionRangeDetailDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebGridSelectionRangeDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSelectionRangeDetailDescription } from "./WebGridSelectionRangeDetailDescription";
/**
 * @hidden
 */
var WebGridSelectionRangeDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebGridSelectionRangeDetailDescriptionMetadata, _super);
    function WebGridSelectionRangeDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebGridSelectionRangeDetailDescriptionMetadata.b = function (a) {
        if (WebGridSelectionRangeDetailDescriptionMetadata.a == null) {
            WebGridSelectionRangeDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebGridSelectionRangeDetailDescriptionMetadata.c(WebGridSelectionRangeDetailDescriptionMetadata.a);
        }
        if (a.k(WebGridSelectionRangeDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:GridSelectionRangeDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("RowStart", "Number:double");
        a.item("RowEnd", "Number:double");
        a.item("ColumnStart", "String");
        a.item("ColumnEnd", "String");
    };
    WebGridSelectionRangeDetailDescriptionMetadata.d = function (a) {
        WebGridSelectionRangeDetailDescriptionMetadata.b(a);
        a.ac("WebGridSelectionRangeDetail", function () { return new WebGridSelectionRangeDetailDescription(); });
        a.ab("WebGridSelectionRangeDetail", WebGridSelectionRangeDetailDescriptionMetadata.a);
    };
    WebGridSelectionRangeDetailDescriptionMetadata.$t = markType(WebGridSelectionRangeDetailDescriptionMetadata, 'WebGridSelectionRangeDetailDescriptionMetadata');
    WebGridSelectionRangeDetailDescriptionMetadata.a = null;
    return WebGridSelectionRangeDetailDescriptionMetadata;
}(Base));
export { WebGridSelectionRangeDetailDescriptionMetadata };
